@@ -37,40 +37,43 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
-use Google::Ads::GoogleAds::V18::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V18::Resources::Campaign;
-use Google::Ads::GoogleAds::V18::Resources::CampaignCriterion;
-use Google::Ads::GoogleAds::V18::Resources::Asset;
-use Google::Ads::GoogleAds::V18::Resources::AssetGroup;
-use Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset;
-use Google::Ads::GoogleAds::V18::Resources::AssetGroupSignal;
-use Google::Ads::GoogleAds::V18::Common::MaximizeConversionValue;
-use Google::Ads::GoogleAds::V18::Common::LocationInfo;
-use Google::Ads::GoogleAds::V18::Common::LanguageInfo;
-use Google::Ads::GoogleAds::V18::Common::TextAsset;
-use Google::Ads::GoogleAds::V18::Common::ImageAsset;
-use Google::Ads::GoogleAds::V18::Common::AudienceInfo;
-use Google::Ads::GoogleAds::V18::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V18::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V18::Enums::AdvertisingChannelTypeEnum
+use Google::Ads::GoogleAds::V19::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V19::Resources::Campaign;
+use Google::Ads::GoogleAds::V19::Resources::CampaignCriterion;
+use Google::Ads::GoogleAds::V19::Resources::CampaignAsset;
+use Google::Ads::GoogleAds::V19::Resources::Asset;
+use Google::Ads::GoogleAds::V19::Resources::AssetGroup;
+use Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset;
+use Google::Ads::GoogleAds::V19::Resources::AssetGroupSignal;
+use Google::Ads::GoogleAds::V19::Common::MaximizeConversionValue;
+use Google::Ads::GoogleAds::V19::Common::LocationInfo;
+use Google::Ads::GoogleAds::V19::Common::LanguageInfo;
+use Google::Ads::GoogleAds::V19::Common::TextAsset;
+use Google::Ads::GoogleAds::V19::Common::ImageAsset;
+use Google::Ads::GoogleAds::V19::Common::AudienceInfo;
+use Google::Ads::GoogleAds::V19::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V19::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V19::Enums::AdvertisingChannelTypeEnum
   qw(PERFORMANCE_MAX);
-use Google::Ads::GoogleAds::V18::Enums::AssetGroupStatusEnum;
-use Google::Ads::GoogleAds::V18::Enums::AssetFieldTypeEnum
+use Google::Ads::GoogleAds::V19::Enums::AssetGroupStatusEnum;
+use Google::Ads::GoogleAds::V19::Enums::AssetFieldTypeEnum
   qw(HEADLINE DESCRIPTION LONG_HEADLINE BUSINESS_NAME LOGO MARKETING_IMAGE SQUARE_MARKETING_IMAGE);
-use Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation;
+use Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V18::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V19::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V19::Services::CampaignService::CampaignOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation;
-use Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation;
+  Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation;
+use Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::AssetGroupService::AssetGroupOperation;
+  Google::Ads::GoogleAds::V19::Services::AssetGroupService::AssetGroupOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation;
+  Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::AssetGroupSignalService::AssetGroupSignalOperation;
-use Google::Ads::GoogleAds::V18::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V19::Services::AssetGroupSignalService::AssetGroupSignalOperation;
+use
+  Google::Ads::GoogleAds::V19::Services::CampaignAssetService::CampaignAssetOperation;
+use Google::Ads::GoogleAds::V19::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -93,20 +96,9 @@ use constant ASSET_GROUP_TEMPORARY_ID              => -3;
 # need to be fixed temporary IDs because they are referenced only once.
 our $next_temp_id = ASSET_GROUP_TEMPORARY_ID - 1;
 
-# The following parameter(s) should be provided to run the example. You can
-# either specify these by changing the INSERT_XXX_ID_HERE values below, or on
-# the command line.
-#
-# Parameters passed on the command line will override any parameters set in
-# code.
-#
-# Running the example with -h will print the command line usage.
-my $customer_id = "INSERT_CUSTOMER_ID_HERE";
-my $audience_id = undef;
-
 # [START add_performance_max_campaign]
 sub add_performance_max_campaign {
-  my ($api_client, $customer_id, $audience_id) = @_;
+  my ($api_client, $customer_id, $audience_id, $brand_guidelines_enabled) = @_;
 
   # [START add_performance_max_campaign_1]
   # Performance Max campaigns require that repeated assets such as headlines
@@ -134,13 +126,15 @@ sub add_performance_max_campaign {
   # leaving no orphaned entities. See:
   # https://developers.google.com/google-ads/api/docs/mutating/overview.
   push @$operations, create_campaign_budget_operation($customer_id);
-  push @$operations, create_performance_max_campaign_operation($customer_id);
+  push @$operations,
+    create_performance_max_campaign_operation($customer_id,
+    $brand_guidelines_enabled);
   push @$operations, @{create_campaign_criterion_operations($customer_id)};
   push @$operations,
     @{
     create_asset_group_operations(
-      $customer_id, $headline_asset_resource_names,
-      $description_asset_resource_names
+      $customer_id,                      $headline_asset_resource_names,
+      $description_asset_resource_names, $brand_guidelines_enabled
     )};
   push @$operations,
     @{create_asset_group_signal_operations($customer_id, $audience_id)};
@@ -167,17 +161,17 @@ sub create_campaign_budget_operation {
 
   # Create a mutate operation that creates a campaign budget operation.
   return
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignBudgetOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignBudgetService::CampaignBudgetOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignBudgetService::CampaignBudgetOperation
         ->new({
-          create => Google::Ads::GoogleAds::V18::Resources::CampaignBudget->new(
+          create => Google::Ads::GoogleAds::V19::Resources::CampaignBudget->new(
             {
               # Set a temporary ID in the budget's resource name so it can be
               # referenced by the campaign in later steps.
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               name => "Performance Max campaign budget #" . uniqid(),
@@ -196,31 +190,31 @@ sub create_campaign_budget_operation {
 # by other objects being created in the same mutate request.
 # [START add_performance_max_campaign_3]
 sub create_performance_max_campaign_operation {
-  my ($customer_id) = @_;
+  my ($customer_id, $brand_guidelines_enabled) = @_;
 
   # Create a mutate operation that creates a campaign operation.
   return
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignService::CampaignOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignService::CampaignOperation
         ->new({
-          create => Google::Ads::GoogleAds::V18::Resources::Campaign->new({
+          create => Google::Ads::GoogleAds::V19::Resources::Campaign->new({
               # Assign the resource name with a temporary ID.
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               name => "Performance Max campaign #" . uniqid(),
               # Set the budget using the given budget resource name.
               campaignBudget =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               # Set the campaign status as PAUSED. The campaign is the only entity in
               # the mutate request that should have its status set.
               status =>
-                Google::Ads::GoogleAds::V18::Enums::CampaignStatusEnum::PAUSED,
+                Google::Ads::GoogleAds::V19::Enums::CampaignStatusEnum::PAUSED,
               # All Performance Max campaigns have an advertisingChannelType of
               # PERFORMANCE_MAX. The advertisingChannelSubType should not be set.
               advertisingChannelType => PERFORMANCE_MAX,
@@ -236,7 +230,7 @@ sub create_performance_max_campaign_operation {
               # article: http://support.google.com/google-ads/answer/7684216.
               # A targetRoas of 3.5 corresponds to a 350% return on ad spend.
               maximizeConversionValue =>
-                Google::Ads::GoogleAds::V18::Common::MaximizeConversionValue->
+                Google::Ads::GoogleAds::V19::Common::MaximizeConversionValue->
                 new({
                   targetRoas => 3.5
                 }
@@ -251,6 +245,10 @@ sub create_performance_max_campaign_operation {
               # can optionally add exclusions to limit traffic to parts of your website.
               urlExpansionOptOut => "false",
 
+              # Set if the campaign is enabled for brand guidelines. For more information
+              # on brand guidelines, see https://support.google.com/google-ads/answer/14934472.
+              brandGuidelinesEnabled => $brand_guidelines_enabled,
+
               # Optional fields.
               startDate => strftime("%Y%m%d", localtime(time + 60 * 60 * 24)),
               endDate   =>
@@ -276,21 +274,21 @@ sub create_campaign_criterion_operations {
   # and one negative location target for Brooklyn (ID=1022762).
   # First, add the positive (negative = false) for New York City.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V19::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               location =>
-                Google::Ads::GoogleAds::V18::Common::LocationInfo->new({
+                Google::Ads::GoogleAds::V19::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V18::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V19::Utils::ResourceNames::geo_target_constant(
                     1023191)}
                 ),
               negative => "false"
@@ -298,21 +296,21 @@ sub create_campaign_criterion_operations {
 
   # Next add the negative target for Brooklyn.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V19::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               location =>
-                Google::Ads::GoogleAds::V18::Common::LocationInfo->new({
+                Google::Ads::GoogleAds::V19::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V18::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V19::Utils::ResourceNames::geo_target_constant(
                     1022762)}
                 ),
               negative => "true"
@@ -320,24 +318,24 @@ sub create_campaign_criterion_operations {
 
   # Set the LANGUAGE campaign criterion.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V19::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               # Set the language.
               # For a list of all language codes, see:
               # https://developers.google.com/google-ads/api/reference/data/codes-formats#expandable-7.
               language =>
-                Google::Ads::GoogleAds::V18::Common::LanguageInfo->new({
+                Google::Ads::GoogleAds::V19::Common::LanguageInfo->new({
                   languageConstant =>
-                    Google::Ads::GoogleAds::V18::Utils::ResourceNames::language_constant(
+                    Google::Ads::GoogleAds::V19::Utils::ResourceNames::language_constant(
                     1000)    # English
                 })})})});
 
@@ -356,14 +354,14 @@ sub create_multiple_text_assets {
   foreach my $text (@$texts) {
     # Create a mutate operation for a text asset.
     push @$operations,
-      Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
       ->new({
         assetOperation =>
-          Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation->
+          Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
           new({
-            create => Google::Ads::GoogleAds::V18::Resources::Asset->new({
+            create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
                 textAsset =>
-                  Google::Ads::GoogleAds::V18::Common::TextAsset->new({
+                  Google::Ads::GoogleAds::V19::Common::TextAsset->new({
                     text => $text
                   })})})});
   }
@@ -395,31 +393,32 @@ sub create_asset_group_operations {
   my (
     $customer_id,
     $headline_asset_resource_names,
-    $description_asset_resource_names
+    $description_asset_resource_names,
+    $brand_guidelines_enabled
   ) = @_;
 
   my $operations = [];
   # Create a mutate operation that creates an asset group operation.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupService::AssetGroupOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupService::AssetGroupOperation
         ->new({
-          create => Google::Ads::GoogleAds::V18::Resources::AssetGroup->new({
+          create => Google::Ads::GoogleAds::V19::Resources::AssetGroup->new({
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               name     => "Performance Max asset group #" . uniqid(),
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               finalUrls       => ["http://www.example.com"],
               finalMobileUrls => ["http://www.example.com"],
               status          =>
-                Google::Ads::GoogleAds::V18::Enums::AssetGroupStatusEnum::PAUSED
+                Google::Ads::GoogleAds::V19::Enums::AssetGroupStatusEnum::PAUSED
             })})});
 
   # For the list of required assets for a Performance Max campaign, see
@@ -439,16 +438,16 @@ sub create_asset_group_operations {
   # Link the headline assets.
   foreach my $resource_name (@$headline_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => HEADLINE
@@ -458,16 +457,16 @@ sub create_asset_group_operations {
   # Link the description assets.
   foreach my $resource_name (@$description_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => DESCRIPTION
@@ -479,20 +478,17 @@ sub create_asset_group_operations {
     @{create_and_link_text_asset($customer_id, "Travel the World",
       LONG_HEADLINE)};
 
-  # Create and link the business name text asset.
+  # Create and link the business name and logo asset.
   push @$operations,
     @{
-    create_and_link_text_asset($customer_id, "Interplanetary Cruises",
-      BUSINESS_NAME)};
+    create_and_link_brand_assets(
+      $customer_id,             $brand_guidelines_enabled,
+      "Interplanetary Cruises", "https://gaagl.page.link/bjYi",
+      "Marketing Logo"
+    )};
 
   # Create and link the image assets.
 
-  # Create and link the logo asset.
-  push @$operations,
-    @{
-    create_and_link_image_asset($customer_id, "https://gaagl.page.link/bjYi",
-      LOGO, "Marketing Logo")};
-
   # Create and link the marketing image asset.
   push @$operations,
     @{
@@ -521,34 +517,34 @@ sub create_and_link_text_asset {
   my $operations = [];
   # Create a new mutate operation for a text asset.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V18::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
-              textAsset => Google::Ads::GoogleAds::V18::Common::TextAsset->new({
+              textAsset => Google::Ads::GoogleAds::V19::Common::TextAsset->new({
                   text => $text
                 })})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -567,14 +563,14 @@ sub create_and_link_image_asset {
   my $operations = [];
   # Create a new mutate operation for an image asset.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V18::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
               # Provide a unique friendly name to identify your asset.
@@ -582,23 +578,23 @@ sub create_and_link_image_asset {
               # name, the new name will be dropped silently.
               name       => $asset_name,
               imageAsset =>
-                Google::Ads::GoogleAds::V18::Common::ImageAsset->new({
+                Google::Ads::GoogleAds::V19::Common::ImageAsset->new({
                   data => get_base64_data_from_url($url)})})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -609,6 +605,133 @@ sub create_and_link_image_asset {
 }
 # [END add_performance_max_campaign_8]
 
+# Creates a list of MutateOperations that create linked brand assets.
+sub create_and_link_brand_assets {
+  my ($customer_id, $brand_guidelines_enabled, $business_name, $logo_url,
+    $logo_name)
+    = @_;
+
+  my $operations = [];
+
+  # Create the text asset.
+  my $text_asset_temp_id = $next_temp_id--;
+  push @$operations,
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
+    new({
+      assetOperation =>
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
+              resourceName =>
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                $customer_id, $text_asset_temp_id
+                ),
+              textAsset => Google::Ads::GoogleAds::V19::Common::TextAsset->new({
+                  text => $business_name
+                })})})});
+
+  # Create the image asset.
+  my $image_asset_temp_id = $next_temp_id--;
+  push @$operations,
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
+    new({
+      assetOperation =>
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
+              resourceName =>
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                $customer_id, $image_asset_temp_id
+                ),
+              # Provide a unique friendly name to identify your asset.
+              # When there is an existing image asset with the same content but a different
+              # name, the new name will be dropped silently.
+              name       => $logo_name,
+              imageAsset =>
+                Google::Ads::GoogleAds::V19::Common::ImageAsset->new({
+                  data => get_base64_data_from_url($logo_url)})})})});
+
+  if ($brand_guidelines_enabled) {
+    # Create CampaignAsset resources to link the Asset resources to the Campaign.
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        campaignAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::CampaignAssetService::CampaignAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::CampaignAsset->new({
+                fieldType => BUSINESS_NAME,
+                campaign  =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
+                  $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
+                  ),
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $text_asset_temp_id
+                  )})})});
+
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        campaignAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::CampaignAssetService::CampaignAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::CampaignAsset->new({
+                fieldType => LOGO,
+                campaign  =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
+                  $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
+                  ),
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $image_asset_temp_id
+                  )})})});
+  } else {
+    # Create AssetGroupAsset resources to link the Asset resources to the AssetGroup.
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        assetGroupAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $text_asset_temp_id
+                  ),
+                assetGroup =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
+                  $customer_id, ASSET_GROUP_TEMPORARY_ID
+                  ),
+                fieldType => BUSINESS_NAME
+              })})});
+
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        assetGroupAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $image_asset_temp_id
+                  ),
+                assetGroup =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
+                  $customer_id, ASSET_GROUP_TEMPORARY_ID
+                  ),
+                fieldType => LOGO
+              })})});
+  }
+
+  return $operations;
+}
+
 # Creates a list of MutateOperations that create asset group signals.
 # [START add_performance_max_campaign_9]
 sub create_asset_group_signal_operations {
@@ -618,23 +741,23 @@ sub create_asset_group_signal_operations {
   return $operations if not defined $audience_id;
 
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupSignalOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupSignalService::AssetGroupSignalOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupSignalService::AssetGroupSignalOperation
         ->new({
           # To learn more about Audience Signals, see:
           # https://developers.google.com/google-ads/api/docs/performance-max/asset-groups#audience_signals
           create =>
-            Google::Ads::GoogleAds::V18::Resources::AssetGroupSignal->new({
+            Google::Ads::GoogleAds::V19::Resources::AssetGroupSignal->new({
               assetGroup =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               audience =>
-                Google::Ads::GoogleAds::V18::Common::AudienceInfo->new({
+                Google::Ads::GoogleAds::V19::Common::AudienceInfo->new({
                   audience =>
-                    Google::Ads::GoogleAds::V18::Utils::ResourceNames::audience(
+                    Google::Ads::GoogleAds::V19::Utils::ResourceNames::audience(
                     $customer_id, $audience_id
                     )})})})});
   return $operations;
@@ -670,10 +793,15 @@ my $api_client = Google::Ads::GoogleAds::Client->new();
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
 
+my $customer_id              = undef;
+my $audience_id              = undef;
+my $brand_guidelines_enabled = "false";
+
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
-  "customer_id=s" => \$customer_id,
-  "audience_id=i" => \$audience_id
+  "customer_id=s"              => \$customer_id,
+  "audience_id=i"              => \$audience_id,
+  "brand_guidelines_enabled=s" => \$brand_guidelines_enabled
 );
 
 # Print the help message if the parameters are not initialized in the code nor
@@ -681,8 +809,10 @@ GetOptions(
 pod2usage(2) if not check_params($customer_id);
 
 # Call the example.
-add_performance_max_campaign($api_client, $customer_id =~ s/-//gr,
-  $audience_id);
+add_performance_max_campaign(
+  $api_client,  $customer_id =~ s/-//gr,
+  $audience_id, $brand_guidelines_enabled
+);
 
 =pod
 
@@ -714,5 +844,6 @@ add_performance_max_campaign.pl [options]
     -customer_id                The Google Ads customer ID.
     -audience_id                [optional] An audience ID to use to improve the
                                 targeting of the Performance Max campaign.
+    -brand_guidelines_enabled	[optional] A boolean value indicating if the campaign is enabled for brand guidelines. Defaults to false.
 
 =cut
