@@ -45,50 +45,53 @@ use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V18::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V18::Resources::Campaign;
-use Google::Ads::GoogleAds::V18::Resources::ShoppingSetting;
-use Google::Ads::GoogleAds::V18::Resources::CampaignCriterion;
-use Google::Ads::GoogleAds::V18::Resources::Asset;
-use Google::Ads::GoogleAds::V18::Resources::AssetGroup;
-use Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset;
-use Google::Ads::GoogleAds::V18::Resources::CampaignConversionGoal;
-use Google::Ads::GoogleAds::V18::Resources::AssetGroupListingGroupFilter;
-use Google::Ads::GoogleAds::V18::Common::MaximizeConversionValue;
-use Google::Ads::GoogleAds::V18::Common::LocationInfo;
-use Google::Ads::GoogleAds::V18::Common::LanguageInfo;
-use Google::Ads::GoogleAds::V18::Common::TextAsset;
-use Google::Ads::GoogleAds::V18::Common::ImageAsset;
-use Google::Ads::GoogleAds::V18::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V18::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V18::Enums::AdvertisingChannelTypeEnum
+use Google::Ads::GoogleAds::V19::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V19::Resources::Campaign;
+use Google::Ads::GoogleAds::V19::Resources::ShoppingSetting;
+use Google::Ads::GoogleAds::V19::Resources::CampaignCriterion;
+use Google::Ads::GoogleAds::V19::Resources::CampaignAsset;
+use Google::Ads::GoogleAds::V19::Resources::Asset;
+use Google::Ads::GoogleAds::V19::Resources::AssetGroup;
+use Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset;
+use Google::Ads::GoogleAds::V19::Resources::CampaignConversionGoal;
+use Google::Ads::GoogleAds::V19::Resources::AssetGroupListingGroupFilter;
+use Google::Ads::GoogleAds::V19::Common::MaximizeConversionValue;
+use Google::Ads::GoogleAds::V19::Common::LocationInfo;
+use Google::Ads::GoogleAds::V19::Common::LanguageInfo;
+use Google::Ads::GoogleAds::V19::Common::TextAsset;
+use Google::Ads::GoogleAds::V19::Common::ImageAsset;
+use Google::Ads::GoogleAds::V19::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V19::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V19::Enums::AdvertisingChannelTypeEnum
   qw(PERFORMANCE_MAX);
-use Google::Ads::GoogleAds::V18::Enums::AssetGroupStatusEnum;
-use Google::Ads::GoogleAds::V18::Enums::AssetFieldTypeEnum
+use Google::Ads::GoogleAds::V19::Enums::AssetGroupStatusEnum;
+use Google::Ads::GoogleAds::V19::Enums::AssetFieldTypeEnum
   qw(HEADLINE DESCRIPTION LONG_HEADLINE BUSINESS_NAME LOGO MARKETING_IMAGE SQUARE_MARKETING_IMAGE);
-use Google::Ads::GoogleAds::V18::Enums::ConversionActionCategoryEnum
+use Google::Ads::GoogleAds::V19::Enums::ConversionActionCategoryEnum
   qw(PURCHASE);
-use Google::Ads::GoogleAds::V18::Enums::ConversionOriginEnum qw(WEBSITE);
-use Google::Ads::GoogleAds::V18::Enums::ListingGroupFilterTypeEnum
+use Google::Ads::GoogleAds::V19::Enums::ConversionOriginEnum qw(WEBSITE);
+use Google::Ads::GoogleAds::V19::Enums::ListingGroupFilterTypeEnum
   qw(UNIT_INCLUDED);
-use Google::Ads::GoogleAds::V18::Enums::ListingGroupFilterListingSourceEnum
+use Google::Ads::GoogleAds::V19::Enums::ListingGroupFilterListingSourceEnum
   qw(SHOPPING);
-use Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation;
+use Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V18::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V19::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V19::Services::CampaignService::CampaignOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation;
-use Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation;
+  Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation;
+use Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::AssetGroupService::AssetGroupOperation;
+  Google::Ads::GoogleAds::V19::Services::AssetGroupService::AssetGroupOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation;
+  Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::CampaignConversionGoalService::CampaignConversionGoalOperation;
+  Google::Ads::GoogleAds::V19::Services::CampaignConversionGoalService::CampaignConversionGoalOperation;
 use
-  Google::Ads::GoogleAds::V18::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation;
-use Google::Ads::GoogleAds::V18::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V19::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation;
+use
+  Google::Ads::GoogleAds::V19::Services::CampaignAssetService::CampaignAssetOperation;
+use Google::Ads::GoogleAds::V19::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -113,7 +116,9 @@ our $next_temp_id = ASSET_GROUP_TEMPORARY_ID - 1;
 
 # [START add_performance_max_retail_campaign]
 sub add_performance_max_retail_campaign {
-  my ($api_client, $customer_id, $merchant_center_account_id, $final_url) = @_;
+  my ($api_client, $customer_id, $merchant_center_account_id, $final_url,
+    $brand_guidelines_enabled)
+    = @_;
 
   # [START add_performance_max_retail_campaign_1]
   # This campaign will override the customer conversion goals.
@@ -148,15 +153,15 @@ sub add_performance_max_retail_campaign {
   push @$operations, create_campaign_budget_operation($customer_id);
   push @$operations,
     create_performance_max_campaign_operation($customer_id,
-    $merchant_center_account_id);
+    $merchant_center_account_id, $brand_guidelines_enabled);
   push @$operations, @{create_campaign_criterion_operations($customer_id)};
   push @$operations, create_asset_group_operation($customer_id, $final_url);
   push @$operations, create_listing_group_filter_operation($customer_id);
   push @$operations,
     @{
     create_asset_and_asset_group_asset_operations(
-      $customer_id, $headline_asset_resource_names,
-      $description_asset_resource_names
+      $customer_id,                      $headline_asset_resource_names,
+      $description_asset_resource_names, $brand_guidelines_enabled
     )};
   push @$operations,
     @{create_conversion_goal_operations($customer_id,
@@ -184,17 +189,17 @@ sub create_campaign_budget_operation {
 
   # Create a mutate operation that creates a campaign budget operation.
   return
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignBudgetOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignBudgetService::CampaignBudgetOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignBudgetService::CampaignBudgetOperation
         ->new({
-          create => Google::Ads::GoogleAds::V18::Resources::CampaignBudget->new(
+          create => Google::Ads::GoogleAds::V19::Resources::CampaignBudget->new(
             {
               # Set a temporary ID in the budget's resource name so it can be
               # referenced by the campaign in later steps.
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               name => "Performance Max retail campaign budget #" . uniqid(),
@@ -213,31 +218,32 @@ sub create_campaign_budget_operation {
 # by other objects being created in the same mutate request.
 # [START add_performance_max_retail_campaign_3]
 sub create_performance_max_campaign_operation {
-  my ($customer_id, $merchant_center_account_id) = @_;
+  my ($customer_id, $merchant_center_account_id, $brand_guidelines_enabled) =
+    @_;
 
   # Create a mutate operation that creates a campaign operation.
   return
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignService::CampaignOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignService::CampaignOperation
         ->new({
-          create => Google::Ads::GoogleAds::V18::Resources::Campaign->new({
+          create => Google::Ads::GoogleAds::V19::Resources::Campaign->new({
               # Assign the resource name with a temporary ID.
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               name => "Performance Max retail campaign #'" . uniqid(),
               # Set the budget using the given budget resource name.
               campaignBudget =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               # Set the campaign status as PAUSED. The campaign is the only entity in
               # the mutate request that should have its status set.
               status =>
-                Google::Ads::GoogleAds::V18::Enums::CampaignStatusEnum::PAUSED,
+                Google::Ads::GoogleAds::V19::Enums::CampaignStatusEnum::PAUSED,
               # All Performance Max campaigns have an advertisingChannelType of
               # PERFORMANCE_MAX. The advertisingChannelSubType should not be set.
               advertisingChannelType => PERFORMANCE_MAX,
@@ -254,14 +260,14 @@ sub create_performance_max_campaign_operation {
               # A targetRoas of 3.5 corresponds to a 350% return on ad spend.
               # For first time users, it's recommended not to set a target ROAS.
               # maximizeConversionValue =>
-              #   Google::Ads::GoogleAds::V18::Common::MaximizeConversionValue->
+              #   Google::Ads::GoogleAds::V19::Common::MaximizeConversionValue->
               #   new({
               #     targetRoas => 3.5
               #   }
               # ),
               # Below is what you would use if you want to maximize conversions.
               # maximizeConversions =>
-              #   Google::Ads::GoogleAds::V18::Common::MaximizeConversions->
+              #   Google::Ads::GoogleAds::V19::Common::MaximizeConversions->
               #   new({
               #     targetCpaMicros => 1000000
               #   }
@@ -271,7 +277,7 @@ sub create_performance_max_campaign_operation {
 
               # Set the shopping settings.
               shoppingSetting =>
-                Google::Ads::GoogleAds::V18::Resources::ShoppingSetting->new({
+                Google::Ads::GoogleAds::V19::Resources::ShoppingSetting->new({
                   merchantId => $merchant_center_account_id,
                   # Optional: To use products only from a specific feed, set feedLabel
                   # to the feed label used in Merchant Center.
@@ -293,6 +299,10 @@ sub create_performance_max_campaign_operation {
               # explicitly surfaced via GMC.
               urlExpansionOptOut => "true",
 
+              # Set if the campaign is enabled for brand guidelines. For more information
+              # on brand guidelines, see https://support.google.com/google-ads/answer/14934472.
+              brandGuidelinesEnabled => $brand_guidelines_enabled,
+
               # Optional fields.
               startDate => strftime("%Y%m%d", localtime(time + 60 * 60 * 24)),
               endDate   =>
@@ -314,23 +324,23 @@ sub create_campaign_criterion_operations {
   # and they can also be retrieved using the GeoTargetConstantService as shown
   # here: https://developers.google.com/google-ads/api/docs/targeting/location-targeting.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V19::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               # Adds one positive location target for New York City (ID=1023191),
               # specifically adding the positive criteria before the negative one.
               location =>
-                Google::Ads::GoogleAds::V18::Common::LocationInfo->new({
+                Google::Ads::GoogleAds::V19::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V18::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V19::Utils::ResourceNames::geo_target_constant(
                     1023191)}
                 ),
               negative => "false"
@@ -338,21 +348,21 @@ sub create_campaign_criterion_operations {
 
   # Next add the negative target for Brooklyn (ID=1022762).
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V19::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               location =>
-                Google::Ads::GoogleAds::V18::Common::LocationInfo->new({
+                Google::Ads::GoogleAds::V19::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V18::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V19::Utils::ResourceNames::geo_target_constant(
                     1022762)}
                 ),
               negative => "true"
@@ -360,24 +370,24 @@ sub create_campaign_criterion_operations {
 
   # Set the LANGUAGE campaign criterion.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V18::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V19::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V19::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               # Set the language.
               # For a list of all language codes, see:
               # https://developers.google.com/google-ads/api/reference/data/codes-formats#expandable-7.
               language =>
-                Google::Ads::GoogleAds::V18::Common::LanguageInfo->new({
+                Google::Ads::GoogleAds::V19::Common::LanguageInfo->new({
                   languageConstant =>
-                    Google::Ads::GoogleAds::V18::Utils::ResourceNames::language_constant(
+                    Google::Ads::GoogleAds::V19::Utils::ResourceNames::language_constant(
                     1000)    # English
                 })})})});
 
@@ -399,14 +409,14 @@ sub create_multiple_text_assets {
   foreach my $text (@$texts) {
     # Create a mutate operation for a text asset.
     push @$operations,
-      Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
       ->new({
         assetOperation =>
-          Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation->
+          Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
           new({
-            create => Google::Ads::GoogleAds::V18::Resources::Asset->new({
+            create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
                 textAsset =>
-                  Google::Ads::GoogleAds::V18::Common::TextAsset->new({
+                  Google::Ads::GoogleAds::V19::Common::TextAsset->new({
                     text => $text
                   })})})});
   }
@@ -439,25 +449,25 @@ sub create_asset_group_operation {
 
   # Create a mutate operation that creates an asset group operation.
   return
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupService::AssetGroupOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupService::AssetGroupOperation
         ->new({
-          create => Google::Ads::GoogleAds::V18::Resources::AssetGroup->new({
+          create => Google::Ads::GoogleAds::V19::Resources::AssetGroup->new({
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               name     => "Performance Max retail asset group #" . uniqid(),
               campaign =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               finalUrls       => [$final_url],
               finalMobileUrls => [$final_url],
               status          =>
-                Google::Ads::GoogleAds::V18::Enums::AssetGroupStatusEnum::PAUSED
+                Google::Ads::GoogleAds::V19::Enums::AssetGroupStatusEnum::PAUSED
             })})});
 }
 # [END add_performance_max_retail_campaign_10]
@@ -472,9 +482,9 @@ sub create_listing_group_filter_operation {
   # Creates a new ad group criterion containing the "default" listing group
   # (All products).
   my $listing_group_filter =
-    Google::Ads::GoogleAds::V18::Resources::AssetGroupListingGroupFilter->new({
+    Google::Ads::GoogleAds::V19::Resources::AssetGroupListingGroupFilter->new({
       assetGroup =>
-        Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+        Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
         $customer_id, ASSET_GROUP_TEMPORARY_ID
         ),
 
@@ -493,10 +503,10 @@ sub create_listing_group_filter_operation {
     });
 
   return
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupListingGroupFilterOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupListingGroupFilterService::AssetGroupListingGroupFilterOperation
         ->new({
           create => $listing_group_filter
         })});
@@ -511,7 +521,8 @@ sub create_asset_and_asset_group_asset_operations {
   my (
     $customer_id,
     $headline_asset_resource_names,
-    $description_asset_resource_names
+    $description_asset_resource_names,
+    $brand_guidelines_enabled
   ) = @_;
 
   my $operations = [];
@@ -532,16 +543,16 @@ sub create_asset_and_asset_group_asset_operations {
   # Link the headline assets.
   foreach my $resource_name (@$headline_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => HEADLINE
@@ -551,16 +562,16 @@ sub create_asset_and_asset_group_asset_operations {
   # Link the description assets.
   foreach my $resource_name (@$description_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
       ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => DESCRIPTION
@@ -572,20 +583,17 @@ sub create_asset_and_asset_group_asset_operations {
     @{create_and_link_text_asset($customer_id, "Travel the World",
       LONG_HEADLINE)};
 
-  # Create and link the business name text asset.
+  # Create and link the business name and logo asset.
   push @$operations,
     @{
-    create_and_link_text_asset($customer_id, "Interplanetary Cruises",
-      BUSINESS_NAME)};
+    create_and_link_brand_assets(
+      $customer_id,             $brand_guidelines_enabled,
+      "Interplanetary Cruises", "https://gaagl.page.link/1Crm",
+      "Logo Image"
+    )};
 
   # Create and link the image assets.
 
-  # Create and link the logo asset.
-  push @$operations,
-    @{
-    create_and_link_image_asset($customer_id, "https://gaagl.page.link/1Crm",
-      LOGO, "Logo Image")};
-
   # Create and link the marketing image asset.
   push @$operations,
     @{
@@ -617,34 +625,34 @@ sub create_and_link_text_asset {
   my $operations = [];
   # Create a new mutate operation for a text asset.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V18::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
-              textAsset => Google::Ads::GoogleAds::V18::Common::TextAsset->new({
+              textAsset => Google::Ads::GoogleAds::V19::Common::TextAsset->new({
                   text => $text
                 })})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -663,14 +671,14 @@ sub create_and_link_image_asset {
   my $operations = [];
   # Create a new mutate operation for an image asset.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetService::AssetOperation->
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
         new({
-          create => Google::Ads::GoogleAds::V18::Resources::Asset->new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
               # Provide a unique friendly name to identify your asset.
@@ -678,23 +686,23 @@ sub create_and_link_image_asset {
               # name, the new name will be dropped silently.
               name       => $asset_name,
               imageAsset =>
-                Google::Ads::GoogleAds::V18::Common::ImageAsset->new({
+                Google::Ads::GoogleAds::V19::Common::ImageAsset->new({
                   data => get_base64_data_from_url($url)})})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V18::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V18::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V18::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -705,6 +713,133 @@ sub create_and_link_image_asset {
 }
 # [END add_performance_max_retail_campaign_8]
 
+# Creates a list of MutateOperations that create linked brand assets.
+sub create_and_link_brand_assets {
+  my ($customer_id, $brand_guidelines_enabled, $business_name, $logo_url,
+    $logo_name)
+    = @_;
+
+  my $operations = [];
+
+  # Create the text asset.
+  my $text_asset_temp_id = $next_temp_id--;
+  push @$operations,
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
+    new({
+      assetOperation =>
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
+              resourceName =>
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                $customer_id, $text_asset_temp_id
+                ),
+              textAsset => Google::Ads::GoogleAds::V19::Common::TextAsset->new({
+                  text => $business_name
+                })})})});
+
+  # Create the image asset.
+  my $image_asset_temp_id = $next_temp_id--;
+  push @$operations,
+    Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation->
+    new({
+      assetOperation =>
+        Google::Ads::GoogleAds::V19::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V19::Resources::Asset->new({
+              resourceName =>
+                Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                $customer_id, $image_asset_temp_id
+                ),
+              # Provide a unique friendly name to identify your asset.
+              # When there is an existing image asset with the same content but a different
+              # name, the new name will be dropped silently.
+              name       => $logo_name,
+              imageAsset =>
+                Google::Ads::GoogleAds::V19::Common::ImageAsset->new({
+                  data => get_base64_data_from_url($logo_url)})})})});
+
+  if ($brand_guidelines_enabled) {
+    # Create CampaignAsset resources to link the Asset resources to the Campaign.
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        campaignAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::CampaignAssetService::CampaignAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::CampaignAsset->new({
+                fieldType => BUSINESS_NAME,
+                campaign  =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
+                  $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
+                  ),
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $text_asset_temp_id
+                  )})})});
+
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        campaignAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::CampaignAssetService::CampaignAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::CampaignAsset->new({
+                fieldType => LOGO,
+                campaign  =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign(
+                  $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
+                  ),
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $image_asset_temp_id
+                  )})})});
+  } else {
+    # Create AssetGroupAsset resources to link the Asset resources to the AssetGroup.
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        assetGroupAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $text_asset_temp_id
+                  ),
+                assetGroup =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
+                  $customer_id, ASSET_GROUP_TEMPORARY_ID
+                  ),
+                fieldType => BUSINESS_NAME
+              })})});
+
+    push @$operations,
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
+      ->new({
+        assetGroupAssetOperation =>
+          Google::Ads::GoogleAds::V19::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          ->new({
+            create =>
+              Google::Ads::GoogleAds::V19::Resources::AssetGroupAsset->new({
+                asset =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset(
+                  $customer_id, $image_asset_temp_id
+                  ),
+                assetGroup =>
+                  Google::Ads::GoogleAds::V19::Utils::ResourceNames::asset_group(
+                  $customer_id, ASSET_GROUP_TEMPORARY_ID
+                  ),
+                fieldType => LOGO
+              })})});
+  }
+
+  return $operations;
+}
+
 # Sorts a list of asset and asset group asset operations.
 #
 # This sorts the list such that all asset operations precede
@@ -764,9 +899,9 @@ sub create_conversion_goal_operations {
   # is biddable in this campaign.
   foreach my $customer_conversion_goal (@$customer_conversion_goals) {
     my $campaign_conversion_goal =
-      Google::Ads::GoogleAds::V18::Resources::CampaignConversionGoal->new({
+      Google::Ads::GoogleAds::V19::Resources::CampaignConversionGoal->new({
         resourceName =>
-          Google::Ads::GoogleAds::V18::Utils::ResourceNames::campaign_conversion_goal(
+          Google::Ads::GoogleAds::V19::Utils::ResourceNames::campaign_conversion_goal(
           $customer_id,
           PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID,
           $customer_conversion_goal->{category},
@@ -788,10 +923,10 @@ sub create_conversion_goal_operations {
     }
 
     push @$operations,
-      Google::Ads::GoogleAds::V18::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V19::Services::GoogleAdsService::MutateOperation
       ->new({
         campaignConversionGoalOperation =>
-          Google::Ads::GoogleAds::V18::Services::CampaignConversionGoalService::CampaignConversionGoalOperation
+          Google::Ads::GoogleAds::V19::Services::CampaignConversionGoalService::CampaignConversionGoalOperation
           ->new({
             update => $campaign_conversion_goal,
             # Set the update mask on the operation. Here the update mask will be
@@ -836,13 +971,15 @@ my $customer_id                = undef;
 my $merchant_center_account_id = undef;
 my $sales_country              = "US";
 my $final_url                  = "http://www.example.com";
+my $brand_guidelines_enabled   = "false";
 
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
   "customer_id=s"                => \$customer_id,
   "merchant_center_account_id=i" => \$merchant_center_account_id,
   "sales_country=s"              => \$sales_country,
-  "final_url=s"                  => \$final_url
+  "final_url=s"                  => \$final_url,
+  "brand_guidelines_enabled=s"   => \$brand_guidelines_enabled
 );
 
 # Print the help message if the parameters are not initialized in the code nor
@@ -853,7 +990,8 @@ pod2usage(2)
 
 # Call the example.
 add_performance_max_retail_campaign($api_client, $customer_id =~ s/-//gr,
-  $merchant_center_account_id, $sales_country, $final_url);
+  $merchant_center_account_id, $sales_country, $final_url,
+  $brand_guidelines_enabled);
 
 =pod
 
@@ -894,4 +1032,5 @@ add_performance_max_retail_campaign.pl [options]
     -sales_country                [optional] The sales country of products to include in the campaign.
     -final_url                    [optional] The final URL for the asset group of the campaign.
 
+    -brand_guidelines_enabled	  [optional] A boolean value indicating if the campaign is enabled for brand guidelines. Defaults to false.
 =cut
