@@ -27,7 +27,8 @@ sub new {
     customerInsightsGroup  => $args->{customerInsightsGroup},
     dimensions             => $args->{dimensions},
     locationCountryFilters => $args->{locationCountryFilters},
-    queryText              => $args->{queryText}};
+    queryText              => $args->{queryText},
+    youtubeReachLocation   => $args->{youtubeReachLocation}};
 
   # Delete the unassigned fields in this object for a more concise JSON payload
   remove_unassigned_fields($self, $args);
