@@ -22,7 +22,9 @@ use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 
 sub new {
   my ($class, $args) = @_;
-  my $self = {assetGroup => $args->{assetGroup}};
+  my $self = {
+    adStrength => $args->{adStrength},
+    assetGroup => $args->{assetGroup}};
 
   # Delete the unassigned fields in this object for a more concise JSON payload
   remove_unassigned_fields($self, $args);
